/* scherzo - Music notation training
 *
 * 	key.h - Common structures and functions for keys
 *
 * Copyright © 2013 Carl Worth
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/ .
 */

#include <stdbool.h>

#ifndef SCHERZO_KEY_H
#define SCHERZO_KEY_H

#include "pitch.h"

typedef struct scherzo_key
{
    /* Pitch class (diatonic) */
    pitch_t pitch;

    /* Number of sharps/flats in key (if any) */
    int num_sharps;
    int num_flats;
} scherzo_key_t;

void
scherzo_key_init (scherzo_key_t *key, pitch_t pitch);

/* Return true if 'pitch' is within the key as spelled.
 *
 * For example, a PITCH(A, SHARP) is not considered as contained
 * within the key of PITCH(B, FLAT).
 */
bool
scherzo_key_contains_pitch (scherzo_key_t *key, pitch_t pitch);

/* For a pitch that is enharmonic with a pitch within 'key', return
 * the key's spelling of that pitch.
 *
 * Otherwise, return the pitch unmodified.
 */
pitch_t
scherzo_key_spell_pitch (scherzo_key_t *key, pitch_t pitch);

#endif /* KEY_H */
